@@ -4,7 +4,7 @@ use 5.006;
 
 package App::Cmd;
 {
-  $App::Cmd::VERSION = '0.317';
+  $App::Cmd::VERSION = '0.319';
 }
 use App::Cmd::ArgProcessor;
 BEGIN { our @ISA = 'App::Cmd::ArgProcessor' };
@@ -16,6 +16,7 @@ use Class::Load ();
 
 use Sub::Exporter -setup => {
   collectors => {
+    -ignore  => \'_setup_ignore',
     -command => \'_setup_command',
     -run     => sub {
       warn "using -run to run your command is deprecated\n";
@@ -47,6 +48,18 @@ sub _setup_command {
   1;
 }
 
+sub _setup_ignore {
+  my ($self, $val, $data ) = @_;
+  my $into = $data->{into};
+
+  Carp::confess "App::Cmd -ignore setup requested for already-setup class"
+    if $into->isa('App::Cmd::Command');
+
+  $self->_register_ignore($into);
+
+  1;
+}
+
 sub _plugin_plugins { return }
 
 
@@ -81,8 +94,16 @@ sub _command {
 
   my %plugin;
   for my $plugin ($self->_plugins) {
+
     Class::Load::load_class($plugin);
 
+    # relies on either the plugin itself registering as ignored
+    # during compile ( use MyApp::Cmd -ignore )
+    # or being explicitly registered elsewhere ( blacklisted )
+    # via $app_cmd->_register_ignore( $class )
+    #  -- kentnl, 2011-09
+    next if $self->should_ignore( $plugin );
+
     die "$plugin is not a " . $want_isa
       unless $plugin->isa($want_isa);
 
@@ -138,6 +159,24 @@ sub _register_command {
     unless grep { $_ eq $cmd_class } @{ $plugins_for{ $class } };
 }
 
+my %ignored_for;
+
+sub should_ignore {
+  my ( $self , $cmd_class ) = @_;
+  my $class = ref $self || $self;
+  for ( @{ $ignored_for{ $class } } ) {
+    return 1 if $_ eq $cmd_class;
+  }
+  return;
+}
+
+sub _register_ignore {
+  my ($self, $cmd_class) = @_;
+  my $class = ref $self || $self;
+  push @{ $ignored_for{ $class } }, $cmd_class
+    unless grep { $_ eq $cmd_class } @{ $ignored_for{ $class } };
+}
+
 sub _module_pluggable_options {
   # my ($self) = @_; # no point in creating these ops, just to toss $self
   return;
@@ -348,7 +387,7 @@ sub usage { $_[0]{usage} };
 
 sub usage_desc {
   # my ($self) = @_; # no point in creating these ops, just to toss $self
-  return "%c %o <command>";
+  return "%c <command> %o";
 }
 
 
@@ -374,6 +413,7 @@ sub _usage_text {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -382,7 +422,7 @@ App::Cmd - write command line apps with less suffering
 
 =head1 VERSION
 
-version 0.317
+version 0.319
 
 =head1 SYNOPSIS
 
@@ -608,7 +648,7 @@ Returns the usage object for the global options.
 
 The top level usage line. Looks something like
 
-  "yourapp [options] <command>"
+  "yourapp <command> [options]"
 
 =head2 global_opt_spec
 
@@ -645,10 +685,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
